@@ -135,7 +135,7 @@ class Authorize:
         form = web.form("state", "code")
         response = authorize_sign_in(form.state, form.code, "profile")
         tx.user.session["uid"] = [response["me"]]
-        tx.user.session["name"] = [response["profile"]["name"]]
+        tx.user.session["name"] = [response["profile"].get("name", "Anonymous")]
         raise web.SeeOther(tx.user.session["return_to"])
 
 
